import { styled } from "@nuskin/foundation-theme"
import { Button as MUIButton } from "@mui/material";
import { ButtonProps } from "./types";

const StyledButton = styled(MUIButton)<ButtonProps>`
  gap: 10px;
  border-radius: 0;
  :focus {
    border: 1px solid #94D6E9 !important;
  };
  :disabled {
    background-color: ${({ theme: { palette }, color = "primary" }) => palette?.[color]?.buttonState?.disabled};
    color: ${({ theme: { palette }, color = "primary" }) => palette?.[color]?.buttonState?.disabledText}
  }
  ${({ size }) => size === 'medium' && `
    padding: 10px 87px;
  `}
  ${({ size }) => size === 'large' && `
    padding: 12px 95px;
  `}
  ${({ variant, theme: { palette }, color = "primary" }) => variant === 'contained' && `
    background-color: ${palette?.[color]?.main};
    :hover {
      background-color: ${palette?.[color]?.buttonState?.hovered};
    }
    :active {
      background-color: ${palette?.[color]?.buttonState?.pressed};
    }
    :focus {
      background-color: ${palette?.[color]?.buttonState?.focused};
    }
  `}
  ${({ variant, theme: { palette }, color = "primary" }) => variant === 'outlined' && `
    border-color: ${palette?.[color]?.main};
    color: ${palette?.[color]?.main};
    :hover {
      border-color: ${palette?.[color]?.buttonState?.hovered};
      color: ${palette?.[color]?.main};
    }
    :active {
      border-color: ${palette?.[color]?.buttonState?.pressed};
      color: ${palette?.[color]?.main};
    }
  `}
  ${({ variant, theme: { palette }, color = "primary" }) => variant === 'text' && `
    text-decoration: underline 1px !important;
    text-underline-offset: 4px;
    padding: 0;
    min-width: auto;
    background-color: transparent !important;
    text-decoration-color: ${palette?.[color]?.main};
    color: ${palette?.[color]?.main};
    :hover {
      color: ${palette?.[color]?.buttonState?.hovered};
      text-decoration-color: ${palette?.[color]?.buttonState?.hovered};
    }
    :active {
      color: ${palette?.[color]?.main};
      text-decoration-color: ${palette?.[color]?.buttonState?.pressed};
    }
  `}
  ${({ iconOnly }) => iconOnly && `
    padding: 10px;
    min-width: unset;
  `}
`;

export default StyledButton;
