/**
 * @author [vijayaprathap Kumar] (vpkumar@nuskin.com)
 * checkbox.tsx
 * @description
 */

import React from "react";

import { render, fireEvent, noop } from "../../../test-utils";
import NsCheckbox from "./NsCheckbox";

// Test suite for CustomCheckbox
describe('CustomCheckbox', () => {
    it('1. should render checkbox with label', () => {
        const { getByLabelText } = render(
            <NsCheckbox name="test-checkbox" label="Test Checkbox" onChange={noop} checked />
        );
        expect(getByLabelText('Test Checkbox')).toBeInTheDocument();
    });

    // Test case to check if the component renders an unchecked checkbox
    test('2. should render unchecked checkbox', () => {
        // Render the CustomCheckbox component with checked=false and an empty handleChange function
        const { getByLabelText } = render(
            <NsCheckbox name="test-checkbox" label="Test Checkbox" checked={false} onChange={noop} />
        );
        const checkbox = getByLabelText('Test Checkbox');
        // Assert that the checkbox is not checked
        expect(checkbox).not.toBeChecked();
    });

    // Test case to check if the component renders a checked checkbox
    test('3. it should render checked checkbox', () => {
        // Render the CustomCheckbox component with checked=true and an empty handleChange function
        const { getByLabelText } = render(
            <NsCheckbox name="test-checkbox" label="Test Checkbox" checked onChange={noop} />
        );
        const checkbox = getByLabelText('Test Checkbox');
        // Assert that the checkbox is not checked
        expect(checkbox).toBeChecked();
    });

    // Test case to check if the handleChange function is called when the checkbox is clicked
    test('calls handleChange when checkbox is clicked', () => {
        // Create a mock handleChange function using Jest's mock function
        const handleChange = jest.fn();
        // Render the CustomCheckbox component with checked=false and the mock handleChange function
        const { getByLabelText } = render(
            <NsCheckbox name="test-checkbox" label="Test Checkbox" checked={false} onChange={handleChange} />
        );
        const checkbox = getByLabelText('Test Checkbox');
        // Simulate a click event on the checkbox
        fireEvent.click(checkbox);
        // Assert that the handleChange function has been called
        expect(handleChange).toHaveBeenCalled();
    });
});