/**
 * @author [vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsCheckbox.tsx
 * @description Story for NsCheckbox component. 
 */

import React, { useState } from "react";
import { ComponentStory, ComponentMeta } from "@storybook/react";

import NsCheckbox from "./NsCheckbox";

// In this case, we're only passing the label prop.
export default {
    title: "Components",
    component: NsCheckbox,
    decorators: [
        (story) => (
            <div style={{ textAlign: "center", marginTop: "20px" }}>{story()}</div>
        ),
    ],
    argTypes: {
        disabled: { control: "boolean" },
        flag: {
            message: { control: 'text' },
            color: { control: 'select' },
        }
    },
    args: {
        label: 'Label Text',
        disabled: false,
        ariaLabel: 'primary checkbox',
        size: 'small',
        flag: {
            message: 'New',
            color: 'accentColorA',
        }
    },
} as ComponentMeta<typeof NsCheckbox>;


export const Checkbox: ComponentStory<typeof NsCheckbox> = (args) => {
    const [isChecked, setIsChecked] = useState(false);

    /*
        When the checkbox changes, we're calling handleChange, 
        which updates the isChecked state and calls the onChange function, 
        passing in the new isChecked value.
    */
    const handleChange = (event: { target: { checked: boolean; }; }) => {
        const isChecked = event.target.checked;
        setIsChecked(isChecked);
    };

    return (
        <NsCheckbox {...args} checked={isChecked} onChange={handleChange} name="test-checkbox" />
    );
};
