/**
 * @author [vijayaprathap Kumar] (vpkumar@nuskin.com)
 * Flag.styled.tsx
 @description Styled Components for Flag
 */


import { Theme } from '@mui/material';
import { styled } from '@nuskin/foundation-theme';
import { PaletteColorNames } from '@nuskin/foundation-theme/src/themes/types';

import { NsFlagSize } from './types';

type NsFlagThemeParams = {
    $size: NsFlagSize;
    $bgColor?: PaletteColorNames;
    theme?: Theme;
};

// Scale value used to divide size from props for create tag tail as per Flag width and height;
const FLAG_SCALE_VALUE = 2;

const FlagHeightMap = {
    'small': 20,
    'medium': 24,
    'large': 28
};

const getFlagHeight = ({ $size }: { $size: NsFlagSize }) => {
    return FlagHeightMap[$size] || FlagHeightMap['small' as NsFlagSize];
}

const makeFlagSize = ({ $size }: { $size: NsFlagSize }) => {
    const sizeValue = getFlagHeight({ $size });
    return sizeValue / FLAG_SCALE_VALUE;
};

const makeFlagBorder = ({ $size, $bgColor = "accentColorA", theme }: NsFlagThemeParams) => {
    return `${makeFlagSize({ $size })}px solid ${theme?.palette?.[$bgColor].main}`
};

export const StyledFlag = styled('span') <NsFlagThemeParams>`
    min-width: 29px;
    height: ${getFlagHeight}px;
    color: ${({ $bgColor = "accentColorA", theme }) => theme?.palette?.[$bgColor].contrastText};
    background: ${({ $bgColor = "accentColorA", theme }) => theme?.palette?.[$bgColor].main};
    position: relative;
    padding: 0 15px;
    display: inline-grid;
    align-content: space-around;
    :before { 
      position: absolute;
      top: 0;
      right: -${makeFlagSize}px;
      content: "";
      width: 0;
      height: 0;
      display: block;
      border-right: ${makeFlagSize}px solid transparent;
      border-top: ${makeFlagBorder};
  }
  :after {
    position: absolute;
    top: 0;
    right: -${makeFlagSize}px;
    content: "";
    width: 0;
    height: ${makeFlagSize}px;
    display: block;
    border-right:  ${makeFlagSize}px solid transparent;
    border-bottom: ${makeFlagBorder};
}
`